#
# Cookbook:: esh_miniflux
# Recipe:: default
#
# Copyright:: 2023, https://easyself.host
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

postgresql_install 'install posgresql' do
  version '14'
  repo_pgdg false
  action :install_server
end

service 'postgresql@14-main' do
  action :nothing
end

postgresql_role 'miniflux' do
  unencrypted_password node['esh']['miniflux']['postgresql']['password']
  login true
  createdb true
end

postgresql_database 'miniflux' do
  owner 'miniflux'
end

apt_repository 'miniflux' do
  uri 'https://repo.miniflux.app/apt/'
  components ['/']
  distribution ''
  trusted true
  action :add
end

package 'miniflux'

file '/etc/miniflux.conf' do
  content node['esh']['miniflux']['configfile']
  owner 'root'
  group 'root'
  mode '0644'
  action :create
end

service 'miniflux' do
  action [:enable, :start]
  subscribes :restart, 'file[/etc/miniflux.conf]', :immediately
end
